==> haskell-email-validate-2.3.2.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.5
id: email-validate-2.3.2.5-6OITRUpuAibAE5sQKLadq2
key: email-validate-2.3.2.5-6OITRUpuAibAE5sQKLadq2
license: BSD3
maintainer: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
author: George Pollard <porges@porg.es>
exposed: True
indefinite: False
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
abi: dc96f365494fc9a3e845f87294abe935
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/email-validate-2.3.2.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/email-validate-2.3.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/email-validate-2.3.2.5
hs-libraries: HSemail-validate-2.3.2.5-6OITRUpuAibAE5sQKLadq2
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15
    bytestring-0.10.8.2 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.5-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.2.5
id: email-validate-2.3.2.5-GhwFBzZTYePVE4jE2knui
key: email-validate-2.3.2.5-GhwFBzZTYePVE4jE2knui
license: BSD3
maintainer: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
author: George Pollard <porges@porg.es>
exposed: True
indefinite: False
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
abi: c414a2254657dc45aad2082e429264cd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/email-validate-2.3.2.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/email-validate-2.3.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/email-validate-2.3.2.5
hs-libraries: HSemail-validate-2.3.2.5-GhwFBzZTYePVE4jE2knui
depends:
    base-4.10.1.0 attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv
    bytestring-0.10.8.2 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
